==> apache-ignite-2.7.0-src.zip: apache-ignite-2.7.0-src/modules/web/src/test/java/org/apache/ignite/internal/websession/WebSessionTransactionalSelfTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.websession;

import org.apache.ignite.testsuites.IgniteIgnore;

/**
 * Tests web sessions with TRANSACTIONAL cache.
 */
public class WebSessionTransactionalSelfTest extends WebSessionSelfTest {
    /** {@inheritDoc} */
    @Override protected String getCacheName() {
        return "partitioned_tx";
    }

    /** {@inheritDoc} */
    @IgniteIgnore(value = "https://issues.apache.org/jira/browse/IGNITE-810", forceFailure = true)
    @Override public void testRestarts() throws Exception {
        // No-op.
    }

    /** {@inheritDoc} */
    @IgniteIgnore(value = "https://issues.apache.org/jira/browse/IGNITE-810", forceFailure = true)
    @Override public void testInvalidatedSession() throws Exception {
        // No-op.
    }

    /** {@inheritDoc} */
    @IgniteIgnore(value = "https://issues.apache.org/jira/browse/IGNITE-810", forceFailure = true)
    @Override public void testClientReconnectRequest() throws Exception {
        // No-op.
    }
}

==> apache-ignite-2.17.0-src.zip: apache-ignite-2.17.0-src/modules/web/src/test/java/org/apache/ignite/internal/websession/WebSessionTransactionalSelfTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.websession;

import org.junit.Ignore;
import org.junit.Test;

/**
 * Tests web sessions with TRANSACTIONAL cache.
 */
public class WebSessionTransactionalSelfTest extends WebSessionSelfTest {
    /** {@inheritDoc} */
    @Override protected String getCacheName() {
        return "partitioned_tx";
    }

    /** {@inheritDoc} */
    @Ignore("https://issues.apache.org/jira/browse/IGNITE-810")
    @Test
    @Override public void testRestarts() {
        // No-op.
    }

    /** {@inheritDoc} */
    @Ignore("https://issues.apache.org/jira/browse/IGNITE-810")
    @Test
    @Override public void testInvalidatedSession() {
        // No-op.
    }

    /** {@inheritDoc} */
    @Ignore("https://issues.apache.org/jira/browse/IGNITE-810")
    @Test
    @Override public void testClientReconnectRequest() {
        // No-op.
    }
}
